import json
import unittest2 as unittest

# from django_alexa.api import ResponseBuilder


class TestAlexaApi(unittest.TestCase):
    
    def test_response_builder(self):
        # data = {
        #    'outputSpeech': {
        #         'type': "PlainText",
        #         'text': "This is a test!",
        #     },
        #     'shouldEndSession': True,          
        # }
        # response = ResponseBuilder(message="This is a test!")
        # self.assertEquals(json.dumps(response.data),
        #                   json.dumps(data))
        pass
